@@ -1,8 +1,8 @@
 #!/bin/sh
 set -e
-cd localapps/
+cd client/localapps/
 ./autogen.sh
 cd -
-cd nbd-proxy/
+cd client/nbd-proxy/
 ./autogen.sh
 cd -
